/* ICONS */
.icon_travel_new:before{
  content:"\f1ea";
}
.item_icon_travel:before{
  content:"\f32e";
	font-family:uicons-regular-rounded !important;
	font-weight:400 !important;
}

/* DEFAULT PHOTO THUMB */
.bg_item_nophoto.bg_item_photo_travel:before{
  content:"\f0f2";
}
ul.generic_list_widget_large_photo .photo .bg_item_photo{
  width:100%;
  padding-bottom:70%;
}

/*VIEW TRAVEL*/
.travel_top {
  display:flex;
}
.travel_top > .travel_left{
  width:45%;
  display:flex;
  padding-right:20px;
}
[dir="rtl"] .travel_top > .travel_left{
  padding-right: 0;
  padding-left: 20px;
}
.travel_top > .travel_right{
  width:55%;
}
.travels_thumbs_nav .slick-slide > div{
  height:80px !important;
  margin-bottom:10px;
}
.travel_top > .travel_left .travels_thumbs_nav{
  width:80px;
  min-width:80px;
  margin-right:20px;
}
[dir="rtl"] .travel_top > .travel_left .travels_thumbs_nav {
  margin-right: 0;
  margin-left: 20px;
}
.travel_top > .travel_left .travels_thumbs_nav img{
  border-width:1px;
  width:98%;
  height:80px;
  object-fit:cover;
  cursor: pointer;
}
.travels_thumbs_main_image{
  flex:1;
  max-width:80%;
}
.travels_thumbs_description {
  padding:10px 0;
  word-break:normal;
}
.travels_thumbs_main {
  border-width:1px;
  height:350px;
  overflow:hidden;
}
.travels_thumbs_nav .slick-arrow{
  font-size:0;
  background:none !important;
  border:0 !important;
  opacity:1 !important;
}
.travels_thumbs_nav .slick-disabled{
  display:none !important;
}
.travels_thumbs_nav .slick-slide{
  outline:0;
}
.travel_responsive_breadcrumb{
  display:none;
}
.travels_thumbs_nav .slick-arrow:before{
  position:absolute;
  display:block;
  font-family:'Font Awesome 6 Free';
  font-size:16px;
  width:30px;
  height:30px;
  line-height:30px;
  color:var(--theme-font-color);
  background:var(--theme-list-background-color);
  border:1px solid var(--theme-border-color);
  margin:auto;
  left:0;
  right:0;
  top:5px;
  font-weight:600;
  z-index:9;
}
.travels_thumbs_nav .slick-prev:before{
  content:"\f077";
}
.travels_thumbs_nav .slick-next:before{
  content:"\f078";
  top:auto;
  bottom:25px;
}
.travel_top > .travel_left .travels_thumbs_main img{
  width:100%;
  height:100%;
  object-fit:cover;
  object-position:center center;
}
.travel_right h2,
.travel_right h3 {
  margin-bottom:10px;
  padding:0;
}
.travel_right h3{
  padding:0;
}
.travel_right h1{
  border-bottom-width:1px;
  padding-bottom:10px;
}
.travels_entrylist .profile_fields > ul{
  padding:10px 0;
}
.travel_right .travel_entrylist_entry_date{
  color:var(--theme-font-color-light);
  font-size:var(--theme-font-size-small);
  margin-bottom:0.625rem;
}
.travel_right .rating {
  margin-bottom:0.625rem;
}
.travel_right .profile_fields > ul > li > span:first-child{
  width:160px;
  word-break: break-word;
}
.travel_right .profile_fields > ul > li > span:last-child{
  font-weight:600;
  color:var(--theme-button-background-color);
  width:auto;
  word-break:break-all;
}
.travel_entrylist_entry_body {
  margin:1.875rem 0 0.625rem;
}
.travels_entrylist .profile_fields > ul li span i{
  display: inline-block;
}
[dir="rtl"] .travels_entrylist .profile_fields > ul li span i{
  margin-left: 4px;
  margin-right: 0;
}
.travel_entrylist_entry_body > h3 {
  font-weight:600;
  border-bottom-width:1px;
  padding-bottom:10px;
  margin-bottom:10px;
}
.travel_entrylist_entry_body p{
  line-height:1.5em;
  margin-bottom:10px;
}
.travel_entrylist_entry_body br{
  display:none;
}
.travel_entrylist_entry_body img{
  max-width:100%;
}
.travel_entrylist_entry_body ul,
.travel_entrylist_entry_body ol{
  margin-bottom:10px;
}
.travel_entrylist_entry_body .travels_tags > a{
  border-radius:5px;
  display:inline-block;
  margin:10px 4px 0 0;
  padding:2px 10px;
  float:none !important;
}
.travel_stats{
  border-top-width:1px;
  border-top-style:dashed;
  padding-top:10px;
}
.travel_stats > a{
  color:var(--theme-font-color);
  font-weight:var(--theme-font-weight-bold);
}
.layout_page_travel_index_view .layout_core_comments h3{
  display:none;
}
/* MANAGE TRAVELS */
.profile_fields ul > .field_textarea span > ul{
  list-style-type:disc;
  padding-left:20px;
  margin-left:-4px;
}
.profile_fields ul > .field_textarea span > ol{
  padding-left:20px;
  margin-left:-6px;
}
ul.travels_entrylist .travel_entrylist_entry_body ul{
  list-style-type:initial;
}
ul.travels_entrylist .travel_entrylist_entry_body ul,
ul.travels_entrylist .travel_entrylist_entry_body ol{
  padding-left:20px;
}
ul.travels_entrylist .travel_entrylist_entry_body br{
  display:none;
}

/* Responsive CSS */
@media (max-width:600px) {
  .travel_right .profile_fields > ul > li > span:first-child {
    width: 90px;
  }
}
/*TRAVEL WIDGETS*/

/* RESPONSIVE */
@media (max-width:1199px) {
  ul.travels_profile_tab > li{
    width: 30%;
  }
}
@media (max-width:991px) {
  ul.travels_profile_tab > li{
    width: 46%;
  }
}
@media(max-width:767px){
  .travels_thumbs_main{
    display:none;
  }
  ul.travels_browse .travels_browse_photo{
    display:block ;
  }
  .travel_top > .travel_left,
  .travel_top > .travel_right,
  .travel_top{
    width:100%;
    display:block;
    padding:0;
  }
  .travel_top > .travel_left .travels_thumbs_nav{
    width:100%;
    margin-bottom:15px;
    margin-right:0;
  }
  .travel_top > .travel_left .travels_thumbs_nav img{
    width:100%;
    height:200px;
    border:0;
    border-radius:8px;
  }
  .travels_thumbs_nav .slick-slide > div{
    height:200px !important;
    margin:0;
  }
  .travel_responsive_breadcrumb{
    display:block;
    font-size:110%;
  }
  .travels_thumbs_nav .slick-dots > li{
    display:inline-block;
    margin:0 3px;
  }
  .travels_thumbs_nav .slick-dots{
    text-align:center;
  }
  .travels_thumbs_nav .slick-dots li button{
    width:8px;
    font-size:0;
    height:8px;
    border-radius:20px;
    background:var(--theme-font-color) !important;
    opacity:.2;
    border:0 !important;
  }
  .travels_thumbs_nav .slick-dots li.slick-active button{
    opacity:1;
  }
  .travel_right > h3{
    display:none;
  }
}
@media(min-width:768px) and (max-width:900px){
  .travel_top > .travel_left .travels_thumbs_main{
    height:300px;
  }
  .travels_thumbs_nav .slick-next:before{
    bottom: auto;
    margin-top: -40px;
  }
}
@media(min-width:768px){
  .travel_top > .travel_left .travels_thumbs_nav{
    max-height:400px;
  }
}
@media (max-width:575px) {
  ul.travels_profile_tab > li {
    width: 100%;
  }
  
}
/*Popup Image*/
[dir="rtl"] .slbWrap {
  text-align: center !important;
}
