<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<script type="text/javascript">
  en4.core.runonce.add(function() {
    new Uploader('#upload_file', {
			removePhotoURL : "<?php echo $this->url(array('controller' => 'photo','action' => 'remove-photo'), 'travel_extended', true); ?>",
      uploadLinkClass : 'buttonlink icon_photos_new',
      uploadLinkTitle : '<?php echo $this->translate("Add Photos");?>',
      uploadLinkDesc : '<?php echo $this->translate("Click \"Add Photos\" to select one or more photos from your computer. After you have selected the photos, they will begin to upload right away. When your upload is finished, click the button below your photo list to save them to your travel listing.");?>'
    });
  });
</script>
<div class="layout_middle">
  <div class="generic_layout_container">
    <div class="breadcrumb_wrap">
      <div class="bizlist_breadcrumb">
        <p><?php echo $this->translate('Travel Listing Photos');?></p>
      </div>
    </div>
  </div>
  <div class="generic_layout_container layout_core_content">
    <div class="upload_form global_form_wrap">
      <?php echo $this->form->render($this) ?>
    </div>
  </div>
</div>
