INSERT IGNORE INTO `engine4_core_menuitems` (`name`, `module`, `label`, `plugin`, `params`, `menu`, `submenu`, `order`) VALUES ('core_main_quickcreate_travel', 'travel', 'Post a New Listing', 'Travel_Plugin_Menus::canCreateTravels', '{"route":"travel_general","action":"create","icon":"fi fi-rr-suitcase-alt"}', 'core_main_quickcreate', '', 10);

UPDATE `engine4_core_menuitems` SET `params` = '{"route":"travel_general","icon":"fi fi-rr-suitcase-alt"}' WHERE `engine4_core_menuitems`.`name` = 'core_main_travel';

UPDATE `engine4_core_menuitems` SET `description` = 'Browse listings, explore categories, and filter results easily' WHERE `engine4_core_menuitems`.`name` = 'core_main_travel';